@@ -21,7 +21,6 @@ data including those used in DeepVariant.
 
 from __future__ import absolute_import
 from __future__ import division
-# removed import for python2 type annotation support
 from __future__ import print_function
 
 import enum
@@ -38,8 +37,8 @@ from nucleus.protos import variants_pb2
 
 DEEPVARIANT_CHANNEL_NAMES = [
     'read base', 'base quality', 'mapping quality', 'strand',
-    'read supports variant', 'base differs from ref', 'alternate allele 1',
-    'alternate allele 2'
+    'read supports variant', 'base differs from ref', 'haplotype tag',
+    'alternate allele 1', 'alternate allele 2'
 ]
 
 
